@@ -1,7 +1,7 @@
 #
 # phpBB2 - MySQL schema
 #
-# $Id: mysql_schema.sql,v 1.35.2.9 2005/10/30 15:17:14 acydburn Exp $
+# $Id: mysql_schema.sql,v 1.35.2.12 2006/02/06 21:32:42 grahamje Exp $
 #
 
 #
@@ -194,7 +194,7 @@ CREATE TABLE phpbb_posts (
 #
 CREATE TABLE phpbb_posts_text (
    post_id mediumint(8) UNSIGNED DEFAULT '0' NOT NULL,
-   bbcode_uid char(10) NOT NULL,
+   bbcode_uid char(10) DEFAULT '' NOT NULL,
    post_subject char(60),
    post_text text,
    PRIMARY KEY (post_id)
@@ -256,6 +256,7 @@ CREATE TABLE phpbb_ranks (
 CREATE TABLE phpbb_search_results (
   search_id int(11) UNSIGNED NOT NULL default '0',
   session_id char(32) NOT NULL default '',
+  search_time int(11) DEFAULT '0' NOT NULL,
   search_array text NOT NULL,
   PRIMARY KEY  (search_id),
   KEY session_id (session_id)
@@ -492,6 +493,8 @@ CREATE TABLE phpbb_users (
    user_new_privmsg smallint(5) UNSIGNED DEFAULT '0' NOT NULL,
    user_unread_privmsg smallint(5) UNSIGNED DEFAULT '0' NOT NULL,
    user_last_privmsg int(11) DEFAULT '0' NOT NULL,
+   user_login_tries smallint(5) UNSIGNED DEFAULT '0' NOT NULL,
+   user_last_login_try int(11) DEFAULT '0' NOT NULL,
    user_emailtime int(11),
    user_viewemail tinyint(1),
    user_attachsig tinyint(1),
