@@ -6,7 +6,7 @@
  *   copyright            : (C) 2001 The phpBB Group
  *   email                : support@phpbb.com
  *
- *   $Id: update_to_latest.php,v 1.1.2.8 2005/10/30 15:17:14 acydburn Exp $
+ *   $Id: update_to_latest.php,v 1.1.2.14 2006/05/20 14:01:48 grahamje Exp $
  *
  ***************************************************************************/
 
@@ -59,7 +59,7 @@ include($phpbb_root_path . 'includes/db.'.$phpEx);
 //
 //
 //
-$updates_to_version = '.0.18';
+$updates_to_version = '.0.21';
 //
 //
 //
@@ -570,7 +570,7 @@ switch ($row['config_value'])
 				$sql[] = 'CREATE TABLE [' . $table_prefix . 'sessions_keys] ([key_id] [char] (32) NOT NULL , [user_id] [int] NOT NULL , [last_ip] [char] (8) NOT NULL , [last_login] [int] NOT NULL) ON [PRIMARY]';
 
 				$sql[] = 'CREATE INDEX [IX_' . $table_prefix . 'sessions_keys] ON [' . $table_prefix . 'sessions_keys]([key_id], [user_id]) ON [PRIMARY]';
-				$sql[] = 'CREATE  INDEX [IX_' . $table_prefix . 'sessions_keys] ON [' . $table_prefix . 'sessions_keys]([last_login]) ON [PRIMARY]';
+				$sql[] = 'CREATE  INDEX [IX_' . $table_prefix . 'sessions_keys_1] ON [' . $table_prefix . 'sessions_keys]([last_login]) ON [PRIMARY]';
 				break;
 
 			case 'msaccess':
@@ -584,6 +584,79 @@ switch ($row['config_value'])
 				break;
 		}
 
+	case '.0.18':
+
+		// Add login columns to user table
+		switch (SQL_LAYER)
+		{
+			case 'mysql':
+			case 'mysql4':
+				$sql[] = "ALTER TABLE " . USERS_TABLE . "
+					ADD COLUMN user_login_tries smallint(5) UNSIGNED DEFAULT '0' NOT NULL";
+				$sql[] = "ALTER TABLE " . USERS_TABLE . "
+					ADD COLUMN user_last_login_try int(11) DEFAULT '0' NOT NULL";
+				break;
+
+			case 'postgresql':
+				$sql[] = "ALTER TABLE " . USERS_TABLE . "
+					ADD COLUMN user_login_tries int2";
+				$sql[] = "ALTER TABLE " . USERS_TABLE . "
+					ALTER COLUMN user_login_tries SET DEFAULT '0'";
+				$sql[] = "ALTER TABLE " . USERS_TABLE . "
+					ADD COLUMN user_last_login_try int4";
+				$sql[] = "ALTER TABLE " . USERS_TABLE . "
+					ALTER COLUMN user_last_login_try SET DEFAULT '0'";
+				break;
+
+			case 'mssql-odbc':
+			case 'mssql':
+				$sql[] = "ALTER TABLE " . USERS_TABLE . " ADD
+					user_login_tries smallint NOT NULL,
+					CONSTRAINT [DF_" . $table_prefix . "users_user_login_tries] DEFAULT (0) FOR [user_login_tries]";
+				$sql[] = "ALTER TABLE " . USERS_TABLE . " ADD
+					user_last_login_try int NOT NULL,
+					CONSTRAINT [DF_" . $table_prefix . "users_user_last_login_try] DEFAULT (0) FOR [user_last_login_try]";
+				break;
+
+			case 'msaccess':
+				$sql[] = "ALTER TABLE " . USERS_TABLE . " ADD
+					user_login_tries smallint NOT NULL";
+				$sql[] = "ALTER TABLE " . USERS_TABLE . " ADD
+					user_last_login_try int NOT NULL";
+				break;
+		}
+
+	case '.0.19':
+
+		// Add search time to the search table
+		switch (SQL_LAYER)
+		{
+			case 'mysql':
+			case 'mysql4':
+				$sql[] = "ALTER TABLE " . SEARCH_TABLE . "
+					ADD COLUMN search_time int(11) DEFAULT '0' NOT NULL";
+				break;
+
+			case 'postgresql':
+				$sql[] = "ALTER TABLE " . SEARCH_TABLE . "
+					ADD COLUMN search_time int4";
+				$sql[] = "ALTER TABLE " . SEARCH_TABLE . "
+					ALTER COLUMN search_time SET DEFAULT '0'";
+				break;
+
+			case 'mssql-odbc':
+			case 'mssql':
+				$sql[] = "ALTER TABLE " . SEARCH_TABLE . " ADD
+					search_time int NOT NULL,
+					CONSTRAINT [DF_" . $table_prefix . "search_results_search_time] DEFAULT (0) FOR [search_time]";
+				break;
+
+			case 'msaccess':
+				$sql[] = "ALTER TABLE " . SEARCH_TABLE . " ADD
+					search_time int NOT NULL";
+				break;
+		}
+
 		break;
 }
 
@@ -999,13 +1072,44 @@ switch ($row['config_value'])
 			VALUES ('max_autologin_time', '0')";
 		_sql($sql, $errored, $error_ary);
 		
+	case '.0.18':
+
+		$sql = 'INSERT INTO ' . CONFIG_TABLE . " (config_name, config_value)
+			VALUES ('max_login_attempts', '5')";
+		_sql($sql, $errored, $error_ary);
+
+		$sql = 'INSERT INTO ' . CONFIG_TABLE . " (config_name, config_value)
+			VALUES ('login_reset_time', '30')";
+		_sql($sql, $errored, $error_ary);
+
+	case '.0.19':
+
+		$sql = 'INSERT INTO ' . CONFIG_TABLE . " (config_name, config_value)
+			VALUES ('search_flood_interval', '15')";
+		_sql($sql, $errored, $error_ary);
+
+		$sql = 'INSERT INTO ' . CONFIG_TABLE . " (config_name, config_value)
+			VALUES ('rand_seed', '0')";
+		_sql($sql, $errored, $error_ary);
+
+	case '.0.20':
+
+		$sql = 'INSERT INTO ' . CONFIG_TABLE . " (config_name, config_value)
+			VALUES ('search_min_chars', '3')";
+		_sql($sql, $errored, $error_ary);
+
 		// We reset those having autologin enabled and forcing the re-assignment of a session id
+		// since there have been changes to the way these are handled from previous versions
 		$sql = 'DELETE FROM ' . SESSIONS_TABLE;
 		_sql($sql, $errored, $error_ary);
+
+		$sql = 'DELETE FROM ' . SESSIONS_KEYS_TABLE;
+		_sql($sql, $errored, $error_ary);
+
 		break;
 
 	default:
-		echo " No updates where required</b></p>\n";
+		echo " No updates were required</b></p>\n";
 		break;
 }
 
@@ -1026,7 +1130,7 @@ switch (SQL_LAYER)
 {
 	case 'mysql':
 	case 'mysql4':
-		$sql = 'OPTIMIZE TABLE ' . $table_prefix . 'auth_access, ' . $table_prefix . 'banlist, ' . $table_prefix . 'categories, ' . $table_prefix . 'config, ' . $table_prefix . 'disallow, ' . $table_prefix . 'forum_prune, ' . $table_prefix . 'forums, ' . $table_prefix . 'groups, ' . $table_prefix . 'posts, ' . $table_prefix . 'posts_text, ' . $table_prefix . 'privmsgs, ' . $table_prefix . 'privmsgs_text, ' . $table_prefix . 'ranks, ' . $table_prefix . 'search_results, ' . $table_prefix . 'search_wordlist, ' . $table_prefix . 'search_wordmatch, ' . $table_prefix . 'smilies, ' . $table_prefix . 'themes, ' . $table_prefix . 'themes_name, ' . $table_prefix . 'topics, ' . $table_prefix . 'topics_watch, ' . $table_prefix . 'user_group, ' . $table_prefix . 'users, ' . $table_prefix . 'vote_desc, ' . $table_prefix . 'vote_results, ' . $table_prefix . 'vote_voters, ' . $table_prefix . 'words';
+		$sql = 'OPTIMIZE TABLE ' . $table_prefix . 'auth_access, ' . $table_prefix . 'banlist, ' . $table_prefix . 'categories, ' . $table_prefix . 'config, ' . $table_prefix . 'disallow, ' . $table_prefix . 'forum_prune, ' . $table_prefix . 'forums, ' . $table_prefix . 'groups, ' . $table_prefix . 'posts, ' . $table_prefix . 'posts_text, ' . $table_prefix . 'privmsgs, ' . $table_prefix . 'privmsgs_text, ' . $table_prefix . 'ranks, ' . $table_prefix . 'search_results, ' . $table_prefix . 'search_wordlist, ' . $table_prefix . 'search_wordmatch, ' . $table_prefix . 'sessions_keys' . $table_prefix . 'smilies, ' . $table_prefix . 'themes, ' . $table_prefix . 'themes_name, ' . $table_prefix . 'topics, ' . $table_prefix . 'topics_watch, ' . $table_prefix . 'user_group, ' . $table_prefix . 'users, ' . $table_prefix . 'vote_desc, ' . $table_prefix . 'vote_results, ' . $table_prefix . 'vote_voters, ' . $table_prefix . 'words';
 		_sql($sql, $errored, $error_ary);
 		break;
 
