@@ -2,9 +2,9 @@
 /***************************************************************************
  *                          lang_faq.php [romn]
  *                            -------------------
- *   begin                : Wednesday Aug 7, 2002
- *   last update          : May 29, 2003
- *   language version     : 3.0
+ *   begin                : Aug 7, 2002
+ *   last update          : Dec 31, 2004
+ *   language version     : 6.0
  *   copyright            : Romanian phpBB online community
  *   website              : http://www.phpbb.ro
  *   copyright 1          : (C) Robert Munteanu
@@ -75,7 +75,7 @@ $faq[] = array("Pot folosi HTML?", "Acest lucru depinde de administrator, care a
 $faq[] = array("Ce sunt <i>Zmbetele</i>?", "Zmbetele sau iconiele emotive sunt imagini mici care pot fi folosite pentru a exprima anumite sentimente folosind un cod scurt. Spre exemplu :) nseamn vesel , :( nseamn trist. Lista complet poate fi vazut n formularul de publicare. ncercai totui s nu i folosii prea mult pentru c pot face un mesaj ilizibil i un moderator se poate hotr s i scoat din mesaj sau s tearg mesajul cu totul.");
 $faq[] = array("Pot publica imagini?", "Imaginile pot fi afiate n mesajele dumneavoastr. Cu toate acestea, nu exist nici o posibilitate n acest forum pentru ncarcarea imaginilor direct n forum. De aceea, trebuie s scriei o legatur ctre o imagine stocat pe un server accesibil publicului, cum ar fi <i>http://un.server.oarecare.ro/imaginea-mea.gif</i>. Nu putei s facei legatura cu imagini de pe calculatorul dumneavoastr (doar dac este un server), nici cu imagini stocate n spatele unui mecanism de autentificare, cum ar fi casuele de mail, site-uri protejate cu parol, etc. Pentru a afia imaginea, folosii fie baliza codului BB [img] sau cod HTML (dac este permis).");
 $faq[] = array("Ce sunt anunurile?" ,"Anunurile deseori conin informaii importante i ar trebui s le citii ct de repede putei. Anunurile apar n partea de sus a fiecrei pagini n forumul de care aparin. Dac putei sau nu posta un anun depinde de permisiunile necesare, care sunt stabilite de administrator.");             
-$faq[] = array("Ce sunt subiectele lipicioase (sticky)?", "Subiectele lipicioase apar sub anunuri n forum i doar pe prima pagin. Deseori sunt destul de importante i ar trebui s le citii dac putei. Ca i cu anunurile, administratorul alege ce permisiuni sunt necessre pentru pentru a le publica.");
+$faq[] = array("Ce sunt subiectele importante?", "Subiectele importante apar sub anunuri n forum i doar pe prima pagin. Deseori sunt destul de importante i ar trebui s le citii dac putei. Ca i cu anunurile, administratorul alege ce permisiuni sunt necessre pentru pentru a le publica.");
 $faq[] = array("Ce sunt subiectele blocate?", "Subiectele sunt blocate fie de ctre moderator, fie de ctre administrator. Nu putei rspunde unui subiect blocat i orice chestionar coninut este nchis automat. Subiectele pot fi nchise din mai multe motive.");
 
 
@@ -90,7 +90,7 @@ $faq[] = array("Cum pot deveni moderatorul unui grup de utilizatori?", "Grupuril
 $faq[] = array("--","Mesaje private");
 $faq[] = array("Nu pot trimite mesaje private!", "Exist trei posibile motive: nu suntei nregistrat i/sau autentificat, administratorul nu a activat mesajele private pentru toi utilizatorii sau administratorul a restricionat pentru dumneavoastr folosirea mesajelor private. n ultimul caz ar trebui s l intrebai ce motive a avut.");
 $faq[] = array("Tot primesc mesaje private nedorite!", "n viitor vom adauga o list de persoane ale cror mesaje s fie ignorate. Deocamdat dac primii n continuare aceste mesaje anunai administratorul, pentru c el are posibilitatea de a opri un utilizator s trimit mesaje private.");
-$faq[] = array("Am primit spam-uri sau mesaje abuzive de la cineva din forum!", "Ne pare ru s auzim acest lucru. Formularul pentru trimiterea unui mesaj include msuri de siguran pentru a observa care utlizatori trimit astfel de mesaje. Ar trebui s trimitei administratorului o copie complet a mesajului primit, inclusiv antetul (acestea ofer detalii despre utilizatorul care a trimis mesajul). Astfel, el poate aciona.");
+$faq[] = array("Am primit spam-uri sau mesaje abuzive de la cineva din forum!", "Ne pare ru s auzim acest lucru. Formularul pentru trimiterea unui mesaj include msuri de siguran pentru a observa care utilizatori trimit astfel de mesaje. Ar trebui s trimitei administratorului o copie complet a mesajului primit, inclusiv antetul (acestea ofer detalii despre utilizatorul care a trimis mesajul). Astfel, el poate aciona.");
 
 //
 // These entries should remain in all languages and for all modifications
@@ -98,7 +98,7 @@ $faq[] = array("Am primit spam-uri sau mesaje abuzive de la cineva din forum!",
 $faq[] = array("--","ntrebri despre phpBB 2");
 $faq[] = array("Cine a scris acest program?", "Acest program (n forma nemodificat) este produs, lansat i aflat sub copyright-ul <a href=\"http://www.phpbb.com/\" target=\"_blank\">grupului phpBB</a>. Este disponibil sub Licena General Public GNU i poate fi distribuit liber; folosii legtura ctre grup mai multe detalii.");
 $faq[] = array("De ce nu este facilitatea X disponibil?", "Acest program a fost scris i liceniat de ctre grupul phpBB. n cazul n care considerai c o facilitate trebuie s fie adaugat, v rugm s vizitai site-ul phpBB.com i s vedei ce are de spus grupul phpBB. V rugm s nu publicai cereri de faciliti pe forumurile de la phpbb.com, pentru c grupul phpBB folosete sourceforge pentru a delega sarcinile legate de noile faciliti. V rugm s trecei prin aceste forumuri i s vedei, dac exist, care este poziia noastr legat de o facilitate i s urmai procedura explicat acolo.");
-$faq[] = array("Cu cine iau legatura pentru probleme legate de abuzuri i/sau juridice legate de acest program?", "Ar trebui s luai legatura cu administratorul forumului. Dac nu putei s facei acest lucru, ar trebui s ncercai cu unul din moderatorii de forumuri i s i intrebai cu cine ai putea lua legatura. Dac tot nu primii rspuns, ar trebui s luai legtura cu posesorul domeniului dumneavoastr (efectuai o interogare whois) sau, dac acesta este pe un domeniu gratuit (yahoo, free.fr, etc.), conducerea sau departamentul pentru abuzuri. Grupul phpBB nu are absolut nici un fel de control i nu poate fi tras la rspundere pentru cum, unde sau de ctre cine este folosit acest program. Este inutil s luai legatura cu grupul phpBB pentru orice fel de probleme juridice care nu sunt legate direct de pagina phpbb.com sau de program n sine. Dac trimitei un mesaj ctre grupul phpBB despre orice folosire a unui ter a acestui program, nu asteptai un rspuns pentru c nu vei primi.");
+$faq[] = array("Cu cine iau legatura pentru probleme legate de abuzuri i/sau juridice legate de acest program?", "Ar trebui s luai legatura cu administratorul forumului. Dac nu putei s facei acest lucru, ar trebui s ncercai cu unul din moderatorii de forumuri i s i intrebai cu cine ai putea lua legatura. Dac tot nu primii rspuns, ar trebui s luai legtura cu posesorul domeniului dumneavoastr (efectuai o interogare whois) sau, dac acesta este pe un domeniu gratuit (yahoo, free.fr, etc.), conducerea sau departamentul pentru abuzuri. Grupul phpBB nu are absolut nici un fel de control i nu poate fi tras la rspundere pentru cum, unde sau de ctre cine este folosit acest program. Este inutil s luai legatura cu grupul phpBB pentru orice fel de probleme juridice care nu sunt legate direct de pagina phpbb.com sau de program n sine. Dac trimitei un mesaj ctre grupul phpBB despre orice folosire a unui ter a acestui program, nu ateptai un rspuns pentru c nu vei primi.");
 
 //
 // This ends the FAQ entries
