@@ -6,7 +6,7 @@
  *     copyright            : (C) 2001 The phpBB Group
  *     email                : support@phpbb.com
  *
- *     $Id: lang_main.php,v 1.85.2.4 2002/06/23 02:47:56 dougk_ff7 Exp $
+ *     $Id: lang_main.php,v 1.85.2.15 2003/06/10 00:31:19 psotfx Exp $
  *
  ****************************************************************************/
 
@@ -19,11 +19,16 @@
  *
  ***************************************************************************/
 
-//
-// Add your details here if wanted, e.g. Name, username, email address, website
-// 2002/08/28 Translated by TankTonk
-// 2002/12/17 updated by Soon-Son Kwon(kss@kldp.org)
-//
+/* CONTRIBUTORS
+	2002-12-15	Philip M. White (pwhite@mailhaven.com)
+		Fixed many minor grammatical problems.
+	2002-08-28	TankTonk
+		FIrst Translation
+	2002-12-17	Soon-Son Kwon(kss@kldp.org)
+		Update
+	2005-02-26	Seok-moon Jang(drssay@gmail.com)
+		Update to 2.0.12
+*/
 
 //
 // The format of this file is ---> $lang['message'] = 'text';
@@ -42,7 +47,7 @@ $lang['DATE_FORMAT'] =  'Y n j'; // This should be changed to the default date f
 // This is optional, if you would like a _SHORT_ message output
 // along with our copyright message indicating you are the translator
 // please add it here.
-// $lang['TRANSLATION'] = 'Translated by TankTonk';
+$lang['TRANSLATION'] = 'Translated by kss & drssay';
 
 //
 // Common, these terms are used
@@ -104,7 +109,7 @@ $lang['AIM'] = 'AIM ּ';
 $lang['MSNM'] = 'MSN ޽';
 $lang['YIM'] = 'Yahoo ޽';
 
-$lang['Forum_Index'] = '%s Խ ε';  // eg. sitename Forum Index, %s can be removed if you prefer
+$lang['Forum_Index'] = '%s Խ ε';   // eg. sitename Forum Index, %s can be removed if you prefer
 
 $lang['Post_new_topic'] = ' ';
 $lang['Reply_to_topic'] = '亯 ޱ';
@@ -125,7 +130,7 @@ $lang['Board_disable'] = '˼մϴٸ  Խ Ͻ  ϴ. ߿ ٽ õ ʽÿ.';
 //
 // Global Header strings
 //
- $lang['Registered_users'] = ' :';
+$lang['Registered_users'] = ' :';
 $lang['Browsing_forum'] = ' Խ ϰ ִ :';
 $lang['Online_users_zero_total'] = ' <b>0</b> ڰ  :: ';
 $lang['Online_users_total'] = ' <b>%d</b>  :: ';
@@ -185,7 +190,6 @@ $lang['No_new_posts_locked'] = 'ο   [  ]';
 $lang['New_posts_locked'] = 'ο  [  ]';
 $lang['Forum_is_locked'] = ' ִ ԽԴϴ.';
 
-
 //
 // Login
 //
@@ -248,7 +252,6 @@ $lang['Rules_moderate'] = '%s Խ  %s <b>ֽϴ</b>'; // %s replaced by a href link
 
 $lang['No_topics_post_one'] = ' Խǿ ÷  ϴ<br /><b> </b> ũ ŬϿ  øʽÿ';
 
-
 //
 // Viewtopic
 //
@@ -490,7 +493,7 @@ $lang['Notification_subject'] = 'ο  ޽ ߽ϴ';
 
 $lang['Find_username'] = ' ̸ ã';
 $lang['Find'] = 'ã';
-$lang['No_match'] = 'ã ';
+$lang['No_match'] = 'ġϴ  ';
 
 $lang['No_post_id'] = ' ID   ʾҽ';
 $lang['No_such_folder'] = ' ʴ ';
@@ -604,6 +607,7 @@ $lang['Profile_updated_inactive'] = '  ƮǾϴٸ ߿   Ǿϴ. ̸ ȮϿ  ٽ  մϴ.  
 $lang['Password_mismatch'] = 'Է йȣ ġ ʽϴ';
 $lang['Current_password_mismatch'] = 'Է  йȣ ͺ̽  Ͱ ġ ʽϴ';
 $lang['Password_long'] = 'йȣ 32 ̳ մϴ';
+$lang['Too_many_registers'] = 'ʹ  Ͻõ Ͽϴ. Ŀ ٽ õϿ ֽʽÿ.';
 $lang['Username_taken'] = '̹   ̸Դϴ';
 $lang['Username_invalid'] = ' ̸    ڸ ̽ϴ';
 $lang['Username_disallowed'] = ' ʴ  ̸Դϴ';
@@ -656,6 +660,16 @@ $lang['Send_email'] = '̸ ';
 $lang['Empty_subject_email'] = '̸  ϼ';
 $lang['Empty_message_email'] = '̸  Էϼ';
 
+//
+// Visual confirmation system strings
+//
+$lang['Confirm_code_wrong'] = 'Է Ȯڵ尡 ùٸ ʽϴ.The confirmation code you entered was incorrect';
+$lang['Too_many_registers'] = ' ǿ õ Ƚ ʰǾϴ. Ŀ ٽ õϿ ֽʽÿ.';
+$lang['Confirm_code_impaired'] = 'If you are visually impaired or cannot otherwise read this code %s%s Ͻʽÿ';
+$lang['Confirm_code'] = 'Ȯڵ';
+$lang['Confirm_code_explain'] = ' ״ ԷϽʽÿ.  ڵ ҹڸ ϸ 0 ȿմϴ.';
+
+
 
 //
 // Memberslist
@@ -807,6 +821,7 @@ $lang['Not_Authorised'] = ' ';
 $lang['You_been_banned'] = 'ϴ  Խǿ ߽ϴ<br />ڼ  ͳ Խ ڿ ϼ';
 
 
+
 //
 // Viewonline
 //
@@ -952,6 +967,7 @@ $lang['tz']['9.5'] = 'GMT + 9.5 ð';
 $lang['tz']['10'] = 'GMT + 10 ð';
 $lang['tz']['11'] = 'GMT + 11 ð';
 $lang['tz']['12'] = 'GMT + 12 ð';
+$lang['tz']['13'] = 'GMT + 13 ð';
 
 $lang['datetime']['Sunday'] = 'Ͽ';
 $lang['datetime']['Monday'] = '';
@@ -1005,7 +1021,7 @@ $lang['An_error_occured'] = ' ߻߽ϴ';
 $lang['A_critical_error'] = 'ġ  ߻߽ϴ';
 
 //
-// That's all Folks!
+// That's all, Folks!
 // -------------------------------------------------
 
 ?>
\ No newline at end of file
